@@ -28,7 +28,7 @@ plot.process_matrix <- function(x, ...) {
 				ggplot(aes(antecedent, consequent)) +
 				geom_raster(aes(fill = n)) +
 				geom_text(aes(label = n), color = "white", fontface = "bold")  +
-				scale_fill_continuous_tableau(name = "Absolute Frequency", palette = "Blue") +
+				scale_fill_continuous_bupaR(name = "Absolute Frequency") +
 				coord_flip() +
 				theme_light() +
 				theme(axis.text.x = element_text(angle = 45, hjust = 1)) -> p
@@ -41,7 +41,7 @@ plot.process_matrix <- function(x, ...) {
 				ggplot(aes(antecedent, consequent)) +
 				geom_raster(aes(fill = rel_n)) +
 				geom_text(aes(label = round(rel_n*100, 2)), color = "white", fontface = "bold") +
-				scale_fill_continuous_tableau(name = "Relative Frequency", palette = "Blue") +
+				scale_fill_continuous_bupaR(name = "Relative Frequency") +
 				theme_light() +
 				coord_flip() +
 				theme(axis.text.x = element_text(angle = 45, hjust = 1))-> p
@@ -52,9 +52,9 @@ plot.process_matrix <- function(x, ...) {
 		} else if(type == "relative-case") {
 			x %>%
 				ggplot(aes(antecedent, consequent)) +
-				geom_raster(aes(fill = rel_n_cases)) +
+				geom_tile(aes(fill = rel_n_cases)) +
 				geom_text(aes(label = round(rel_n_cases*100, 2)), color = "white", fontface = "bold") +
-				scale_fill_continuous_tableau(name = "Relative Case Frequency", palette = "Blue") +
+				scale_fill_continuous_bupaR(name = "Relative Case \nFrequency") +
 				theme_light() +
 				coord_flip() +
 				theme(axis.text.x = element_text(angle = 45, hjust = 1))-> p
@@ -64,9 +64,9 @@ plot.process_matrix <- function(x, ...) {
 		} else if(type == "absolute-case") {
 			x %>%
 				ggplot(aes(antecedent, consequent)) +
-				geom_raster(aes(fill = n_cases)) +
+				geom_tile(aes(fill = n_cases)) +
 				geom_text(aes(label = n_cases), color = "white", fontface = "bold") +
-				scale_fill_continuous_tableau(name = "Absolute Case Frequency", palette = "Blue") +
+				scale_fill_continuous_bupaR(name = "Absolute \nCase Frequency") +
 				theme_light() +
 				coord_flip() +
 				theme(axis.text.x = element_text(angle = 45, hjust = 1))-> p
@@ -76,10 +76,10 @@ plot.process_matrix <- function(x, ...) {
 		} else if(type == "relative-antecedent") {
 			x %>%
 				ggplot(aes(antecedent, consequent)) +
-				geom_raster(aes(fill = rel_antecedent)) +
+				geom_tile(aes(fill = rel_antecedent)) +
 				geom_text(aes(label = round(rel_antecedent*100, 2)), color = "white", fontface = "bold") +
 				facet_grid(antecedent~., scales = "free", space = "free") +
-				scale_fill_continuous_tableau(name = "Relative Frequency (antecedent based)", palette = "Blue") +
+				scale_fill_continuous_bupaR(name = "Relative Frequency \n(antecedent based)") +
 				theme_light() +
 				coord_flip() +
 				theme(axis.text.x = element_text(angle = 45, hjust = 1),
@@ -90,10 +90,10 @@ plot.process_matrix <- function(x, ...) {
 		} else if(type == "relative-consequent") {
 			x %>%
 				ggplot(aes(antecedent, consequent)) +
-				geom_raster(aes(fill = rel_consequent)) +
+				geom_tile(aes(fill = rel_consequent)) +
 				geom_text(aes(label = round(rel_consequent*100,2)), color = "white", fontface = "bold") +
 				facet_grid(~consequent, scales = "free", space = "free") +
-				scale_fill_continuous_tableau(name = "Relative Frequency (consequent based)", palette = "Blue") +
+				scale_fill_continuous_bupaR(name = "Relative Frequency \n(consequent based)") +
 				theme_light() +
 				coord_flip() +
 				theme(axis.text.x = element_text(angle = 45, hjust = 1),
@@ -108,7 +108,7 @@ plot.process_matrix <- function(x, ...) {
 			ggplot(aes(antecedent, consequent)) +
 			geom_raster(aes(fill = flow_time)) +
 			geom_text(aes(label =round(flow_time, 2)), color = "white", fontface = "bold") +
-			scale_fill_continuous_tableau(name = paste0("Flow time in ", attr(type, "units")), palette = "Red") +
+			scale_fill_continuous_bupaR(name = paste0("Flow time in ", attr(type, "units"))) +
 			theme_light() +
 			coord_flip() +
 			theme(axis.text.x = element_text(angle = 45, hjust = 1),
