@@ -1,9 +1,6 @@
 
 #' @title Process Map
-#'
-#'
 #' @description A function for creating a process map of an event log.
-#' @param eventlog The event log object for which to create a process map
 #' @param type A process map type, which can be created with the functions frequency, performance and custom. The first type focusses on the frequency aspect of a process, while the second one focussed on processing time. The third one allows custom attributes to be used.
 
 #' @param sec A secondary process map type. Values are shown between brackets.
@@ -24,7 +21,8 @@
 #' @param fixed_node_pos Deprecated, please use the 'layout' parameter instead.
 #' @param ... Deprecated arguments
 #'
-#'
+#' @inheritParams dotted_chart
+
 #' @examples
 #' \dontrun{
 #' library(eventdataR)
@@ -38,7 +36,20 @@
 #' @export process_map
 
 
-process_map <- function(eventlog,type,sec,type_nodes,type_edges,sec_nodes,sec_edges,rankdir,render,fixed_edge_width,layout,fixed_node_pos,...) {
+process_map <- function(log,
+						type = frequency("absolute"),
+						sec = NULL,
+						type_nodes = type,
+						type_edges = type,
+						sec_nodes = sec,
+						sec_edges = sec,
+						rankdir = "LR",
+						render = T,
+						fixed_edge_width = F,
+						layout = layout_pm(),
+						fixed_node_pos = NULL,
+						eventlog = deprecated(),
+						...)  {
 	UseMethod("process_map")
 }
 
@@ -46,7 +57,7 @@ process_map <- function(eventlog,type,sec,type_nodes,type_edges,sec_nodes,sec_ed
 #' @export
 
 
-process_map.eventlog <- function(eventlog,
+process_map.eventlog <- function(log,
 								 type = frequency("absolute"),
 								 sec = NULL,
 								 type_nodes = type,
@@ -58,8 +69,11 @@ process_map.eventlog <- function(eventlog,
 								 fixed_edge_width = F,
 								 layout = layout_pm(),
 								 fixed_node_pos = NULL,
+								 eventlog = deprecated(),
 								 ...) {
 
+	eventlog <- lifecycle_warning_eventlog(log, eventlog)
+
 	from <- NULL
 	to <- NULL
 	label_numeric <- NULL
@@ -93,9 +107,6 @@ process_map.eventlog <- function(eventlog,
 		layout <- layout_pm(fixed_positions = fixed_node_pos)
 	}
 
-
-
-
 	if (any(is.na(eventlog %>% pull(!!timestamp_(eventlog))))) {
 		warning("Some of the timestamps in the supplied event log are missing (NA values). This may result in a invalid process map!")
 
@@ -231,10 +242,11 @@ process_map.eventlog <- function(eventlog,
 		nodes %>%
 			full_join(nodes_secondary, by = c("ACTIVITY_CLASSIFIER_", "from_id")) %>%
 			mutate(label = if_end(ACTIVITY_CLASSIFIER_,
-								  ACTIVITY_CLASSIFIER_,
-								  str_replace(paste0(label, "\n","(", map(sec_label, ~str_split(.x, "\n")[[1]][2]), ")"), "\n\\(\\)",""))) -> nodes
+								  label,
+								  str_replace(paste0(label, "\n","(", map(sec_label, ~str_split(.x, "\n")[[1]][2]), ")"), "\n\\(\\)",""))) %>%
+			mutate(label = if_end(ACTIVITY_CLASSIFIER_, recode(ACTIVITY_CLASSIFIER_, ARTIFICIAL_START = "Start",ARTIFICIAL_END = "End"),
+								  label)) -> nodes
 	}
-
 	if(!is.null(sec_edges)) {
 		edges_secondary <- attr(sec_edges, "create_edges")(base_precedence, sec_edges, extra_data) %>%
 			select(from_id, to_id, label) %>%
@@ -298,10 +310,32 @@ process_map.eventlog <- function(eventlog,
 	min_level <- min(nodes_df$color_level)
 	max_level <- max(nodes_df$color_level[nodes_df$color_level < Inf])
 
+	# start_id <- nodes %>% filter(ACTIVITY_CLASSIFIER_ == "ARTIFICIAL_START") %>% pull(from_id)
+	# end_id <- nodes %>% filter(ACTIVITY_CLASSIFIER_ == "ARTIFICIAL_END") %>% pull(from_id)
+	#
+	# other_ids <- nodes %>% filter(!(from_id %in% c(start_id, end_id))) %>% pull(from_id)
+	#
+	# bind_rows(
+	# 	tibble(from_id = start_id, to_id = other_ids),
+	# 	tibble(from_id = other_ids, to_id = end_id)
+	# ) %>%
+	# 	mutate(style = "invis") %>%
+	# 	mutate(penwidth = 0) -> extra_edges
+	#
+	#
+	# extra_edges %>%
+	# 	anti_join(edges, by = c("from_id", "to_id")) -> extra_edges
+	#
+	# bind_rows(edges, extra_edges) -> edges
+
+
+
+
 	create_edge_df(from = edges$from_id,
 				   to = edges$to_id,
 				   label = edges$label,
 				   penwidth = edges$penwidth,
+				   # style = edges$style,
 				   color = attr(type_edges, "color_edges"),
 				   fontname = "Arial",
 				   fontsize = 10,
@@ -365,7 +399,7 @@ process_map.eventlog <- function(eventlog,
 #' @export
 
 
-process_map.grouped_eventlog <- function(eventlog,
+process_map.grouped_eventlog <- function(log,
 								 type = frequency("absolute"),
 								 sec = NULL,
 								 type_nodes = type,
@@ -377,7 +411,10 @@ process_map.grouped_eventlog <- function(eventlog,
 								 fixed_edge_width = F,
 								 layout = layout_pm(),
 								 fixed_node_pos = NULL,
+								 eventlog = deprecated(),
 								 ...) {
+	log <- lifecycle_warning_eventlog(log, eventlog)
+
 	m <- mapping(eventlog)
 
 	eventlog %>%
@@ -416,3 +453,28 @@ process_map.grouped_eventlog <- function(eventlog,
 	}
 
 }
+
+#' @describeIn process_map Process map for activitylog
+#' @export
+
+process_map.activitylog <- function(log,
+										 type = frequency("absolute"),
+										 sec = NULL,
+										 type_nodes = type,
+										 type_edges = type,
+										 sec_nodes = sec,
+										 sec_edges = sec,
+										 rankdir = "LR",
+										 render = T,
+										 fixed_edge_width = F,
+										 layout = layout_pm(),
+										 fixed_node_pos = NULL,
+										 eventlog = deprecated(),
+										 ...) {
+	log <- lifecycle_warning_eventlog(log, eventlog)
+
+	process_map.eventlog(to_eventlog(log), type, sec, type_nodes, type_edges, sec_nodes, sec_edges, rankdir,
+						 render, fixed_edge_width, layout, fixed_node_pos)
+
+
+}
